@@ -75,13 +75,15 @@ sub init_and_watch {
 
     if($delay =~ /\D/) {
         $WATCHER = Log::Log4perl::Config::Watch->new(
-                          file   => $config,
-                          signal => $delay,
+                          file         => $config,
+                          signal       => $delay,
+                          l4p_internal => 1,
                    );
     } else {
         $WATCHER = Log::Log4perl::Config::Watch->new(
                           file           => $config,
                           check_interval => $delay,
+                          l4p_internal   => 1,
                    );
     }
 
@@ -525,6 +527,8 @@ sub config_read {
 ###########################################
     my($config) = @_;
 
+    die "Configuration not defined" unless defined $config;
+
     my @text;
 
     $CONFIG_FILE_READS++;  # Count for statistical purposes
@@ -558,7 +562,7 @@ sub config_read {
        require Net::LDAP;
        require Log::Log4perl::Config::LDAPConfigurator;
 
-       return Log::Log4perl::Config::LDAPConfigurator::parse($config);
+       return Log::Log4perl::Config::LDAPConfigurator->new->parse($config);
 
     }else{
 
